import { InjectionToken, Directive, ElementRef, Inject, Input, Renderer2, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * @record
 */

/**
 * @record
 */

const config = new InjectionToken('config');
const NEW_CONFIG = new InjectionToken('NEW_CONFIG');
const INITIAL_CONFIG = new InjectionToken('INITIAL_CONFIG');
const initialConfig = {
    img: '/assets/images/spinner.svg',
    loaderStyles: {
        'position': 'absolute',
        'left': '0',
        'right': '0',
        'top': '0',
        'bottom': '0',
        'background': 'rgba(255, 255, 255, 0.8)',
        'z-index': '50',
    },
    imgStyles: {
        'position': 'absolute',
        'top': '50%',
        'left': '50%',
        'transform': 'translate(-50%, -50%)',
        'max-width': '20px',
        'max-height': '20px',
    },
    hostStyles: {
        'position': 'relative'
    }
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class AngularLoaderDirective {
    /**
     * @param {?} _config
     * @param {?} _el
     * @param {?} _renderer
     */
    constructor(_config, _el, _renderer) {
        this._config = _config;
        this._el = _el;
        this._renderer = _renderer;
        this.loaderStyles = _config.loaderStyles;
        this.imgStyles = _config.imgStyles;
        this.hostStyles = _config.hostStyles;
        this.img = _config.img;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set show(value) {
        if (!value) {
            this.loaderEl ? this._setStyles(this.loaderEl, { display: 'none' }) : null;
            return;
        }
        this.loaderEl = this._renderer.createElement('div');
        const /** @type {?} */ img = this._renderer.createElement('img');
        this._renderer.appendChild(this._el.nativeElement, this.loaderEl);
        this._renderer.appendChild(this.loaderEl, img);
        this._setStyles(this._el.nativeElement, this.hostStyles);
        this._setStyles(this.loaderEl, this.loaderStyles);
        this._setStyles(img, this.imgStyles);
        this._renderer.setAttribute(img, 'src', this.img);
    }
    /**
     * @param {?} element
     * @param {?} styles
     * @return {?}
     */
    _setStyles(element, styles) {
        Object.keys(styles).forEach((key) => {
            this._renderer.setStyle(element, key, styles[key]);
        });
    }
}
AngularLoaderDirective.decorators = [
    { type: Directive, args: [{
                selector: '[loader]',
            },] },
];
/** @nocollapse */
AngularLoaderDirective.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [config,] },] },
    { type: ElementRef, },
    { type: Renderer2, },
];
AngularLoaderDirective.propDecorators = {
    "show": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class NgxLoaderIndicatorModule {
    /**
     * @param {?=} configValue
     * @return {?}
     */
    static forRoot(configValue) {
        return {
            ngModule: NgxLoaderIndicatorModule,
            providers: [
                {
                    provide: NEW_CONFIG,
                    useValue: configValue
                },
                {
                    provide: INITIAL_CONFIG,
                    useValue: initialConfig
                },
                {
                    provide: config,
                    useFactory: _configFactory,
                    deps: [INITIAL_CONFIG, NEW_CONFIG]
                },
            ]
        };
    }
}
NgxLoaderIndicatorModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [
                    AngularLoaderDirective,
                ],
                exports: [
                    AngularLoaderDirective,
                ]
            },] },
];
/**
 * \@internal
 * @param {?} initConfig
 * @param {?} configValue
 * @return {?}
 */
function _configFactory(initConfig, configValue) {
    return (typeof configValue === 'function') ? configValue() : Object.assign({}, initConfig, configValue);
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { config, NEW_CONFIG, INITIAL_CONFIG, initialConfig, NgxLoaderIndicatorModule, _configFactory, AngularLoaderDirective };
//# sourceMappingURL=ngx-loader-indicator.js.map
