import { InjectionToken, Directive, ElementRef, Inject, Input, Renderer2, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';

var config = new InjectionToken('config');
var NEW_CONFIG = new InjectionToken('NEW_CONFIG');
var INITIAL_CONFIG = new InjectionToken('INITIAL_CONFIG');
var initialConfig = {
    img: '/assets/images/spinner.svg',
    loaderStyles: {
        'position': 'absolute',
        'left': '0',
        'right': '0',
        'top': '0',
        'bottom': '0',
        'background': 'rgba(255, 255, 255, 0.8)',
        'z-index': '50',
    },
    imgStyles: {
        'position': 'absolute',
        'top': '50%',
        'left': '50%',
        'transform': 'translate(-50%, -50%)',
        'max-width': '20px',
        'max-height': '20px',
    },
    hostStyles: {
        'position': 'relative'
    }
};
var AngularLoaderDirective = /** @class */ (function () {
    function AngularLoaderDirective(_config, _el, _renderer) {
        this._config = _config;
        this._el = _el;
        this._renderer = _renderer;
        this.loaderStyles = _config.loaderStyles;
        this.imgStyles = _config.imgStyles;
        this.hostStyles = _config.hostStyles;
        this.img = _config.img;
    }
    Object.defineProperty(AngularLoaderDirective.prototype, "show", {
        set: function (value) {
            if (!value) {
                this.loaderEl ? this._setStyles(this.loaderEl, { display: 'none' }) : null;
                return;
            }
            this.loaderEl = this._renderer.createElement('div');
            var img = this._renderer.createElement('img');
            this._renderer.appendChild(this._el.nativeElement, this.loaderEl);
            this._renderer.appendChild(this.loaderEl, img);
            this._setStyles(this._el.nativeElement, this.hostStyles);
            this._setStyles(this.loaderEl, this.loaderStyles);
            this._setStyles(img, this.imgStyles);
            this._renderer.setAttribute(img, 'src', this.img);
        },
        enumerable: true,
        configurable: true
    });
    AngularLoaderDirective.prototype._setStyles = function (element, styles) {
        var _this = this;
        Object.keys(styles).forEach(function (key) {
            _this._renderer.setStyle(element, key, styles[key]);
        });
    };
    return AngularLoaderDirective;
}());
AngularLoaderDirective.decorators = [
    { type: Directive, args: [{
                selector: '[loader]',
            },] },
];
AngularLoaderDirective.ctorParameters = function () { return [
    { type: undefined, decorators: [{ type: Inject, args: [config,] },] },
    { type: ElementRef, },
    { type: Renderer2, },
]; };
AngularLoaderDirective.propDecorators = {
    "show": [{ type: Input },],
};
var NgxLoaderIndicatorModule = /** @class */ (function () {
    function NgxLoaderIndicatorModule() {
    }
    NgxLoaderIndicatorModule.forRoot = function (configValue) {
        return {
            ngModule: NgxLoaderIndicatorModule,
            providers: [
                {
                    provide: NEW_CONFIG,
                    useValue: configValue
                },
                {
                    provide: INITIAL_CONFIG,
                    useValue: initialConfig
                },
                {
                    provide: config,
                    useFactory: _configFactory,
                    deps: [INITIAL_CONFIG, NEW_CONFIG]
                },
            ]
        };
    };
    return NgxLoaderIndicatorModule;
}());
NgxLoaderIndicatorModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [
                    AngularLoaderDirective,
                ],
                exports: [
                    AngularLoaderDirective,
                ]
            },] },
];
function _configFactory(initConfig, configValue) {
    return (typeof configValue === 'function') ? configValue() : Object.assign({}, initConfig, configValue);
}

export { config, NEW_CONFIG, INITIAL_CONFIG, initialConfig, NgxLoaderIndicatorModule, _configFactory, AngularLoaderDirective };
//# sourceMappingURL=ngx-loader-indicator.js.map
